aboutsummaryrefslogtreecommitdiff
path: root/src/kadmin/ktutil
diff options
context:
space:
mode:
authorRichard Basch <probe@mit.edu>1997-02-19 02:06:04 +0000
committerRichard Basch <probe@mit.edu>1997-02-19 02:06:04 +0000
commit26799ad1e58dc5a7539bde822bc93a0a7acba97d (patch)
tree55445ec34c89b8a8542265ba952164c0b03f0890 /src/kadmin/ktutil
parent5971bf00db7bdbdd8ba3f36c9d1ea358dadcb8c9 (diff)
downloadkrb5-26799ad1e58dc5a7539bde822bc93a0a7acba97d.zip
krb5-26799ad1e58dc5a7539bde822bc93a0a7acba97d.tar.gz
krb5-26799ad1e58dc5a7539bde822bc93a0a7acba97d.tar.bz2
Renamed getst() to getstr() to avoid conflicts with krb4.h definition
git-svn-id: svn://anonsvn.mit.edu/krb5/trunk@9912 dc483132-0cff-0310-8789-dd5450dbe970
Diffstat (limited to 'src/kadmin/ktutil')
-rw-r--r--src/kadmin/ktutil/ktutil_funcs.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/kadmin/ktutil/ktutil_funcs.c b/src/kadmin/ktutil/ktutil_funcs.c
index 64b7272..8429169 100644
--- a/src/kadmin/ktutil/ktutil_funcs.c
+++ b/src/kadmin/ktutil/ktutil_funcs.c
@@ -182,16 +182,16 @@ krb5_error_code ktutil_write_keytab(context, list, name)
#ifdef KRB5_KRB4_COMPAT
/*
* getst() takes a file pointer, a string and a count. It reads from
* the file until either it has read "count" characters, or until it
* reads a null byte. When finished, what has been read exists in the
* given string "s". If "count" characters were actually read, the
* last is changed to a null, so the returned string is always null-
* terminated. getst() returns the number of characters read,
* including the null terminator.
*/
-int getst(fp, s, n)
+int getstr(fp, s, n)
FILE *fp;
register char *s;
int n;
@@ -241,9 +241,9 @@ krb5_error_code ktutil_read_srvtab(context, name, list)
memset(sname, 0, sizeof (sname));
memset(sinst, 0, sizeof (sinst));
memset(srealm, 0, sizeof (srealm));
- if (!(getst(fp, sname, SNAME_SZ) > 0 &&
- getst(fp, sinst, INST_SZ) > 0 &&
- getst(fp, srealm, REALM_SZ) > 0 &&
+ if (!(getstr(fp, sname, SNAME_SZ) > 0 &&
+ getstr(fp, sinst, INST_SZ) > 0 &&
+ getstr(fp, srealm, REALM_SZ) > 0 &&
fread(&kvno, 1, 1, fp) > 0 &&
fread((char *)key, sizeof (key), 1, fp) > 0))
break;
@@ -182,16 +182,16 @@ krb5_error_code ktutil_write_keytab(context, list, name)
#ifdef KRB5_KRB4_COMPAT
/*
- * getst() takes a file pointer, a string and a count. It reads from
+ * getstr() takes a file pointer, a string and a count. It reads from
* the file until either it has read "count" characters, or until it
* reads a null byte. When finished, what has been read exists in the
@@ -182,16 +182,16 @@ krb5_error_code ktutil_write_keytab(context, list, name)
* given string "s". If "count" characters were actually read, the
* last is changed to a null, so the returned string is always null-
- * terminated. getst() returns the number of characters read,
+ * terminated. getstr() returns the number of characters read,
* including the null terminator.
*/